@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10169 2017-08-13 03:48:13Z Lavender $
+# $Id: setup.py 10199 2017-08-20 02:22:54Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-13 11:48:13 +0800 (週日, 13 八月 2017) $
-# $Revision: 10169 $ 
+# $Date: 2017-08-20 10:22:54 +0800 (週日, 20 八月 2017) $
+# $Revision: 10199 $ 
 
 import os
 import sys
@@ -38,8 +38,11 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
     logger.info("-----Start copy templates-----")
     for root, dirs, files in os.walk(os.path.join(SETUP_DIR, "static")):
         for d in dirs:
-            if not os.path.exists(os.path.join(staticDir, d)):
-                os.mkdir(os.path.join(staticDir, d))
+            index = os.path.join(root, d).index("static") + len("static/")
+            path = os.path.join(
+                staticDir, os.path.join(os.path.join(root, d))[index:])
+            if not os.path.exists(path):
+                os.mkdir(path)
                 
     if not os.path.exists(os.path.join(baseDir, "fixtures")):
         os.mkdir(os.path.join(baseDir, "fixtures"))
@@ -130,10 +133,15 @@ def loadData(language):
     os.system("%s manage.py loaddata %s" % (sys.executable, data))
     
     from cms.models.pagemodel import Page
+    from cms.models.titlemodels import Title
     from cms.api import copy_plugins_to_language
     
     for page in Page.objects.all():
         copy_plugins_to_language(page, "zh-hant", language)
+    for title in Title.objects.all():
+        title.language = language
+        title.save()
+    
         
 
 if __name__ == "__main__":
